package db;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.security.crypto.bcrypt.BCrypt;

public class DBconn {

	private Connection con = null;
	private static DBconn instance;

	private void createConnection() {
		try {
			String url = "jdbc:sqlite:test.db";
			con = DriverManager.getConnection(url);
		} catch (SQLException e) {
			con = null;
		}
	}

	private void closeConnection() throws SQLException {
		if (con == null)
			return;
		con.close();
		con = null;
	}	

	public void insertUser(String username, String password) throws SQLException {
		if (con == null || con.isClosed())
			return;

		PreparedStatement stmt = con.prepareStatement("INSERT INTO users VALUES(?, ?);");
		stmt.setString(1, username);
		stmt.setString(2, BCrypt.hashpw(password, BCrypt.gensalt(12)));
		stmt.executeUpdate();
		stmt.close();
	}

	public boolean checkPassword(String user, String password) throws SQLException {
		String query = "select password from users where username=?;";
		PreparedStatement stmt = con.prepareStatement(query);
		stmt.setString(1, user);
		ResultSet rs = stmt.executeQuery();
		String password_hash = null;
		while (rs.next()) {
			password_hash = rs.getString(1);
		}
		stmt.close();
		if (password_hash == null)
			return false;
		return BCrypt.checkpw(password, password_hash);
	}

	private DBconn() {
		createConnection();
	}

	public static DBconn getInstance() {
		if (instance == null)
			instance = new DBconn();
		return instance;
	}

	@Override
	protected void finalize() throws Throwable {
		super.finalize();
		closeConnection();
	}
}
